@@ -10,6 +10,18 @@ use Carp;
 use Test::More;
 use Test::Exception;
 
+use Env qw(LC_ALL LC_CTYPE LC_COLLATE LANG);
+
+BEGIN {
+    use POSIX ":locale_h";
+    my $locale = "en_US.UTF-8";
+    if (setlocale(+LC_ALL, $locale)) {
+        $LC_ALL = $LC_CTYPE = $LC_COLLATE = $LANG = $locale;
+    } else {
+        warn "$0: Can't setlocale(LC_ALL, '$locale'): $!";
+    }
+}
+
 $|++;
 
 my @Pragmata = (
